@@ -85,6 +85,7 @@ post '/model' => sub ($c) {
   my $v = $c->validation;
   $v->required('model');
   $v->required('groups');
+  $v->optional('clone');
   if ($v->failed->@*) {
     $c->flash(error => 'Could not update model');
     return $c->redirect_to('model');
@@ -100,9 +101,18 @@ post '/model' => sub ($c) {
       $specs->{parameter}{$g} = [ split /\s*,\s*/, $group_params->[$i] ];
       $i++;
     }
-    store($specs, $model_file);
-    $c->flash(message => 'Update parameters successful');
-    return $c->redirect_to($c->url_for('index')->query(model => $v->param('model')));
+    if ($v->param('clone')) {
+      $synth = Synth::Config->new(model => $v->param('clone'));
+      $model_file = SETTINGS . $synth->model . '.dat';
+      store($specs, $model_file);
+      $c->flash(message => 'Clone model successful');
+      return $c->redirect_to($c->url_for('index')->query(model => $v->param('clone')));
+    }
+    else {
+      store($specs, $model_file);
+      $c->flash(message => 'Update parameters successful');
+      return $c->redirect_to($c->url_for('index')->query(model => $v->param('model')));
+    }
   }
   else {
     my $init_file = Mojo::File->new(SETTINGS . 'initial.set');
@@ -122,6 +132,7 @@ post '/model' => sub ($c) {
 get '/edit_model' => sub ($c) {
   my $v = $c->validation;
   $v->required('model');
+  $v->optional('clone');
   if ($v->failed->@*) {
     $c->flash(error => 'Could not edit model');
     return $c->redirect_to($c->url_for('index')->query(model => $v->param('model')));
@@ -129,14 +140,14 @@ get '/edit_model' => sub ($c) {
   my $synth = Synth::Config->new(model => $v->param('model'));
   my $model_file = SETTINGS . $synth->model . '.dat';
   my $specs = -e $model_file ? retrieve($model_file) : undef;
-  my $groups;
-  $groups = join ',', $specs->{group}->@* if exists $specs->{group};
+  my $groups = exists $specs->{group} ? join ',', $specs->{group}->@* : undef;
   $c->render(
     template   => 'edit_model',
     model      => $v->param('model'),
     groups     => $groups,
     group_list => $specs->{group},
     specs      => $specs->{parameter},
+    clone      => $v->param('clone'),
   );
 } => 'edit_model';
 
@@ -155,7 +166,12 @@ get '/remove' => sub ($c) {
     $c->flash(message => 'Remove setting successful');
     return $c->redirect_to($c->url_for('index')->query(model => $v->param('model'), name => $v->param('name')));
   }
-  elsif ($synth->model) {
+  elsif ($v->param('name') && !($v->param('id'))) {
+    $synth->remove_settings(name => $v->param('name'));
+    $c->flash(message => 'Remove named settings successful');
+    return $c->redirect_to($c->url_for('index')->query(model => $v->param('model')));
+  }
+  elsif ($synth->model && !$v->param('name')) {
     $synth->remove_model;
     my $model_file = Mojo::File->new(SETTINGS . $synth->model . '.dat');
     $model_file->remove;
@@ -188,6 +204,10 @@ get '/edit_setting' => sub ($c) {
     $c->flash(error => 'No known model');
     return $c->redirect_to('index');
   }
+  my $models = $synth->recall_models;
+  for my $m (@$models) {
+    $m =~ s/_/ /g;
+  }
   my $selected = {
     group      => $group,
     parameter  => $parameter,
@@ -206,6 +226,7 @@ get '/edit_setting' => sub ($c) {
     id       => $id,
     name     => $name,
     model    => $model,
+    models   => $models,
     selected => $selected,
   );
 } => 'edit_setting';
@@ -337,24 +358,23 @@ __DATA__
 <div class="row">
   <div class="col">
     <button type="submit" id="search" class="btn btn-primary"><i class="fa-solid fa-magnifying-glass"></i> Search</button>
-% if ($model) {
-    <a href="<%= url_for('edit_setting')->query(model => $model, name => $name, group => $group) %>" id="new_setting" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
-% }
     <a href="<%= url_for('model') %>" class="btn btn-success" id="new_model"><i class="fa-solid fa-database"></i> New model</a>
 % if ($model) {
-    <a href="<%= url_for('edit_model')->query(model => $model) %>" id="edit_model" class="btn btn-success"><i class="fa-solid fa-pencil"></i> Edit model</a>
-
-    <a href="<%= url_for('remove')->query(model => $model) %>" id="remove_model" class="btn btn-danger" onclick="if(!confirm('Remove model?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove model</a>
+    <a href="<%= url_for('edit_setting')->query(model => $model, name => $name, group => $group) %>" id="new_setting" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
+%   if ($name) {
+    <a href="<%= url_for('remove')->query(model => $model, name => $name) %>" id="remove_name" class="btn btn-danger" onclick="if(!confirm('Remove <%= $name %> settings?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove settings</a>
+%   }
 % }
   </div>
 </div>
 </form>
+% if ($settings && @$settings) {
 <p></p>
 <table class="table table-hover">
 <thead>
   <tr>
     <th scope="col">Edit</th>
-    <th scope="col">Name</th>
+    <th scope="col">Setting name</th>
     <th scope="col">Group</th>
     <th scope="col">Param</th>
     <th scope="col">Control</th>
@@ -362,37 +382,43 @@ __DATA__
   </tr>
 </thead>
 <tbody>
-% for my $s (@$settings) {
-%   my $id = (keys(%$s))[0];
-%   my $setting = (values(%$s))[0];
-%   my $edit_url = build_edit_url($model, $id, $setting);
+%   for my $s (@$settings) {
+%     my $id = (keys(%$s))[0];
+%     my $setting = (values(%$s))[0];
+%     my $edit_url = build_edit_url($model, $id, $setting);
 <tr>
+  <td><a href="<%= $edit_url %>" class="btn btn-sm btn-outline-secondary"><i class="fa-solid fa-pencil"></i></a></td>
+  <td><%= $setting->{name} %></td>
+  <td><%= $setting->{group} %></td>
+  <td><%= $setting->{parameter} %></td>
+  <td><i><%= $setting->{control} %></i></td>
   <td>
-    <a href="<%= $edit_url %>" class="btn btn-sm btn-outline-secondary"><i class="fa-solid fa-pencil"></i></a>
-  </td>
-  <td>
-    <%= $setting->{name} %>
-  </td>
-  <td>
-    <%= $setting->{group} %>
-  </td>
-  <td>
-    <%= $setting->{parameter} %>
-  </td>
-  <td>
-    <i><%= $setting->{control} %></i>
-  </td>
-  <td>
-%   if ($setting->{group_to}) {
-    to <%= $setting->{param_to} %> of <%= $setting->{group_to} %>
-%   }
-%   if ($setting->{value}) {
+%     if ($setting->{group_to}) {
+    <%= $setting->{group_to} %> <%= $setting->{param_to} %>
+%     }
+%     if ($setting->{value}) {
     <%= $setting->{value} %> <%= $setting->{unit} %>
-%   }
+%     }
   </td>
 </tr>
-% }
+%   }
 </table>
+% } elsif (!$model) {
+<p></p>
+<table class="table table-hover">
+<thead>
+  <tr>
+    <th scope="col">Edit &nbsp; Model name</th>
+  </tr>
+</thead>
+<tbody>
+%   for my $m (@$models) {
+<tr>
+  <td><a href="<%= url_for('edit_model')->query(model => $m) %>" class="btn btn-sm btn-outline-secondary"><i class="fa-solid fa-pencil"></i></a> &nbsp; <%= ucfirst $m %></td>
+</tr>
+%   }
+</table>
+% }
 
 
 @@ model.html.ep
@@ -437,23 +463,27 @@ __DATA__
 @@ edit_model.html.ep
 % layout 'default';
 <p></p>
+<form action="<%= url_for('update_model') %>" method="post">
 <div class="row">
   <div class="col">
     <label for="model">Model:</label>
+% if ($clone) {
+    <input type="hidden" name="model" value="<%= $model %>">
+    <input type="hidden" name="groups" value="<%= $groups %>">
+    <input type="text" name="clone" id="clone" class="form-control" required>
+% } else {
     <input type="text" name="model" id="model" value="<%= $model %>" class="form-control" disabled readonly>
+% }
   </div>
 </div>
 <p></p>
 <div class="row">
   <div class="col">
-    <label for="group">Group:</label>
-    <input type="text" id="group" value="<%= $groups %>" class="form-control" disabled readonly>
+    <label for="groups">Groups:</label>
+    <input type="text" id="groups" value="<%= $groups %>" class="form-control" disabled readonly>
   </div>
 </div>
 <p></p>
-<form action="<%= url_for('update_model') %>" method="post">
-  <input type="hidden" name="model" value="<%= $model %>">
-  <input type="hidden" name="groups" value="<%= $groups %>">
 % for my $g (@$group_list) {
   <label for="<%= $g %>"><%= $g %>:</label>
   <input type="text" name="group" id="<%= $g %>" value="<%= join ',', $specs->{$g}->@* %>" class="form-control" placeholder="<%= $g %> parameter1, param2, etc.">
@@ -461,7 +491,13 @@ __DATA__
 % }
   <div class="row">
     <div class="col">
+% if ($clone) {
+      <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> New model</button>
+% } else {
       <button type="submit" class="btn btn-primary"><i class="fa-solid fa-arrow-rotate-right"></i> Update model</button>
+      <a href="<%= url_for('remove')->query(model => $model) %>" id="remove_model" class="btn btn-danger" onclick="if(!confirm('Remove model?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove model</a>
+      <a href="<%= url_for('edit_model')->query(model => $model, clone => 1) %>" id="clone_model" class="btn btn-success"><i class="fa-solid fa-copy"></i> Clone</a>
+% }
       <a href="<%= url_for('index')->query(model => $model) %>" id="cancel" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
     </div>
   </div>
@@ -475,7 +511,12 @@ __DATA__
   <input type="hidden" name="id" value="<%= $id %>">
 <div class="row">
   <div class="col">
-    <input type="text" name="model" id="model" value="<%= ucfirst $model %>" class="form-control" placeholder="Model name" required>
+    <select name="model" id="model" class="form-select" required>
+      <option value="">Model name...</option>
+% for my $m (@$models) {
+      <option value="<%= $m %>" <%= $models && $model && lc($m) eq lc($model) ? 'selected' : '' %>><%= ucfirst $m %></option>
+% }
+    </select>
   </div>
   <div class="col">
     <input type="text" name="name" id="name" value="<%= $name %>" class="form-control" placeholder="Setting name" required>
