@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0039';
+our $VERSION = '0.0040';
 
 use Moo;
 use strictures 2;
@@ -80,7 +80,7 @@ sub make_setting {
       { id => $id },
     );
   }
-  else {
+  elsif ($name) {
     $id = $self->_sqlite->insert(
       $self->model,
       {
@@ -221,7 +221,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0039
+version 0.0040
 
 =head1 SYNOPSIS
 
@@ -313,8 +313,12 @@ given B<model>.
 
 Save a named setting and return the record id.
 
-The B<name> is required. If an B<id> is given, an update is performed.
-Otherwise, a database insert is made.
+The B<name> is required to perform an insert. If an B<id> is given, an
+update is performed.
+
+The setting is a single JSON field that can contain any key/value
+pairs. These pairs B<must> include at least a C<group> to be
+searchable.
 
 Example:
 
